@@ -2,64 +2,61 @@
 postgres database layer
 =======================
 
-This module provides the class :class:`PostgresDb` for to connect and interact
-with a Postgres database server.
+this module provides the class :class:`PostgresDb` to connect and interact with a Postgres database server.
 
-The communication with the database driver is done with great help of the
+the communication with the database driver is done with great help of the
 `psycopg2 pypi package <https://pypi.org/project/psycopg2>`_.
 
 
 basic usage of ae.db_pg
 -----------------------
 
-For to create an instance of the class :class:`PostgresDb` you first have to create a
-:class:`~ae.sys_core.SystemBase` instance. This can be done either programmatically
-by providing an application instance (of the class :class:`~ae.ae_console.ConsoleApp`
-or an inherited sub-class of it) plus any database parameters, like
-required credentials and any database configuration features/options::
+to create an instance of the class :class:`PostgresDb` you first have to create a :class:`~ae.sys_core.SystemBase`
+instance. this can be done either programmatically by providing an application instance (of the class
+:class:`~ae.ae_console.ConsoleApp` or an inherited sub-class of it) plus any database parameters, like required
+credentials and any database configuration features/options::
 
     app = ConsoleApp()
     system = SystemBase('system-id', app, dict(User='user name', Password='password`, Dbname=...), ...)
 
-Alternatively provide all system-specific info within the :ref:`ae config files<config-files>`
-and let :class:`~ae.sys_core.UsedSystems` load it::
+alternatively provide all system-specific info within the :ref:`ae config files<config-files>` and let
+:class:`~ae.sys_core.UsedSystems` load it::
 
     system = used_systems['system-id']
 
-Finally pass the database parameters in `system` for to create an instance of :class:`PostgresDb`::
+finally pass the database parameters in `system` to create an instance of :class:`PostgresDb`::
 
     pg_db = PostgresDb(system)
 
-Then call the :meth:`~PostgresDb.connect` method of this instance for to connect to the
-Postgres database server::
+then call the :meth:`~PostgresDb.connect` method of this instance to connect to the Postgres database server::
 
     error_message = pg_db.connect()
     if error_message:
         print(error_message)
 
-If the connection could not be established then  :meth:`~PostgresDb.connect` is returning an error
-message string. If the return value is an empty string then you can use all the methods provided by
-:class:`~ae.db_core.DbBase`, like e.g. :meth:`~ae.db_core.DbBase.update`::
+if the connection could not be established then  :meth:`~PostgresDb.connect` is returning an error message string. if
+the return value is an empty string then you can use all the methods provided by :class:`~ae.db_core.DbBase`, like e.g.
+:meth:`~ae.db_core.DbBase.update`::
 
     error_message = pg_db.update('my_table`, {'my_col': 'new value'})
     if error_message:
         print(error_message)
         error_message = pg_db.rollback()
 
-An explicit call of :meth:`~ae.db_core.DbBase.rollback` is only needed if you use transactions (autocommit is False).
-In this case you should also use :meth:`~ae.db_core.DbBase.commit` at the end of each transaction for to store
-any data updates::
+an explicit call of :meth:`~ae.db_core.DbBase.rollback` is only needed if you use transactions (autocommit is False).
+in this case you should also use :meth:`~ae.db_core.DbBase.commit` at the end of each transaction to store any data
+updates::
 
     error_message = pg_db.commit()
 
-Alternatively you can use the `commit` argument that is provided by the :class:`~ae.db_core.DbBase`
-DML methods: by passing a `True` value to this argument, the method will automatically execute a
-:meth:`~ae.db_core.DbBase.commit` call for you if no error occurred in the DML method::
+alternatively you can use the `commit` argument that is provided by the :class:`~ae.db_core.DbBase` DML methods: by
+passing a `True` value to this argument, the method will automatically execute a :meth:`~ae.db_core.DbBase.commit` call
+for you if no error occurred in the DML method::
 
     error_message = pg_db.update('table`, {'column': 369}, commit=True)
 
-Finally after all database actions are done you can close the connection to the databases server
-with the :meth:`~ae.db_core.DbBase.close` method::
+finally after all database actions are done you can close the connection to the databases server with the
+:meth:`~ae.db_core.DbBase.close` method::
 
     error_message = pg_db.close()
 
@@ -73,7 +70,7 @@ from ae.sys_core import SystemBase      # type: ignore  # for mypy
 from ae.db_core import DbBase           # type: ignore  # for mypy
 
 
-__version__ = '0.2.4'
+__version__ = '0.2.5'
 
 
 class PostgresDb(DbBase):
@@ -85,10 +82,10 @@ class PostgresDb(DbBase):
 
         :class:`~ae.sys_core.SystemBase` (defined in the module :mod:`ae.sys_core`) is providing
         the credentials and features, which get retrieved from :ref:`config-files`, then converted
-        by :meth:`~ae.db_core.DbBase.connect_params` into :ref:`connection parameters` for to connect
+        by :meth:`~ae.db_core.DbBase.connect_params` into :ref:`connection parameters` to connect
         to the Postgres database.
 
-        For connections via SSL to the Postgres server you have to add either the connection parameters
+        for connections via SSL to the Postgres server you have to add either the connection parameters
         **sslmode**, **sslcert** and **sslkey** or **sslrootcert** and **sslcrl** (depending
         on the configuration of your server).
 
@@ -133,9 +130,9 @@ class PostgresDb(DbBase):
         :return:                last error message or empty string if no errors occurred.
 
         .. hint::
-            Overwriting generic execute_sql for Postgres because if auto_commit is False then a db error
+            overwriting generic execute_sql for Postgres because if auto_commit is False then a db error
             is invalidating the connection until it gets rolled back (optionally to a save-point).
-            Unfortunately psycopg2 does not provide/implement save-points. Could be done alternatively with
+            unfortunately psycopg2 does not provide/implement save-points. could be done alternatively with
             execute("SAVEPOINT NonAutoCommErrRollback") but RELEASE/ROLLBACK makes it complicated (see also
             https://stackoverflow.com/questions/2370328/continuing-a-transaction-after-primary-key-violation-error)::
 
@@ -148,7 +145,7 @@ class PostgresDb(DbBase):
                         self.conn.releaseSavepoint(save_point)
                 return self.last_err_msg
 
-            Therefore KISS - a simple rollback will do it also.
+            therefore KISS - a simple rollback will do it also.
 
         """
         if self.conn or not self.connect():
